Various common functions that arise when working often with geohashes
gh_delta(precision)Length-2 numeric vector; the first element is the latitude (y-coordinate) half-width at the input
precision, the second element is the longitude (x-coordinate).
Caveat coder: not much is done in the way of consistency checking since this is a convenience function. So e.g. real-valued "precision"s will give results.
http://geohash.org/ ( Gustavo Niemeyer's original geohash service )
gh_delta(6)
#> [1] 0.002746582 0.005493164